Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(482)

Unified Diff: net/android/http_auth_negotiate_android.h

Issue 1414313002: Allow dynamic updating of authentication policies (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix IOS compile problem - attempt 3 Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/android/http_auth_negotiate_android.h
diff --git a/net/android/http_auth_negotiate_android.h b/net/android/http_auth_negotiate_android.h
index 56990cee900301ae179068fe0e85a6c57832aa07..160a354d4e4535c86ea0dcc8e12a5b68015cfcf3 100644
--- a/net/android/http_auth_negotiate_android.h
+++ b/net/android/http_auth_negotiate_android.h
@@ -19,6 +19,7 @@
namespace net {
class HttpAuthChallengeTokenizer;
+class HttpAuthPreferences;
namespace android {
@@ -55,9 +56,10 @@ class NET_EXPORT_PRIVATE JavaNegotiateResultWrapper {
// for the full details.
class NET_EXPORT_PRIVATE HttpAuthNegotiateAndroid {
public:
- // Creates an object for one negotiation session. |account_type| is the
- // Android account type, used by Android to find the correct authenticator.
- explicit HttpAuthNegotiateAndroid(const std::string& account_type);
+ // Creates an object for one negotiation session. |prefs| are the
+ // authentication preferences. In particular they include the Android account
+ // type, which is used to connect to the correct Android Authenticator.
+ explicit HttpAuthNegotiateAndroid(HttpAuthPreferences* prefs);
asanka 2015/11/25 19:00:09 Let's pass in const references for the auth handle
aberent 2015/11/26 15:58:00 Sadly we can't, because most of the auth handlers
~HttpAuthNegotiateAndroid();
// Register the JNI for this class.
@@ -113,7 +115,7 @@ class NET_EXPORT_PRIVATE HttpAuthNegotiateAndroid {
private:
void SetResultInternal(int result, const std::string& token);
- std::string account_type_;
+ HttpAuthPreferences* prefs_;
bool can_delegate_;
bool first_challenge_;
std::string server_auth_token_;

Powered by Google App Engine
This is Rietveld 408576698